#!/usr/bin/env python
# -*- coding: utf-8 -*-
#

class DataKind:
    FILE = 'file'  # filename
    MMAP_FILE = 'mmap_file'  # mmap file
    MEM_SEQ = 'mem_seq'  # data list in memory
